[![Build Status](https://github.com/andgineer/opensearch-log/workflows/CI/badge.svg)](https://github.com/andgineer/opensearch-log/actions)
[![Coverage](https://raw.githubusercontent.com/andgineer/opensearch-log/python-coverage-comment-action-data/badge.svg)](https://htmlpreview.github.io/?https://github.com/andgineer/opensearch-log/blob/python-coverage-comment-action-data/htmlcov/index.html)
# opensearch-log

opensearch-log is a Python logging handler for direct and efficient log transmission to
OpenSearch or AWS CloudWatch.

It can also be used for local JSON logging to stdout.

With context manager or function decorator you can add additional fields to log messages.

# Documentation

[opensearch-log](https://andgineer.github.io/opensearch-log/en/)

# Developers

Do not forget to run `. ./activate.sh`.

# Scripts
    make help

## Coverage report
* [Codecov](https://app.codecov.io/gh/andgineer/opensearch-log/tree/main/src%2Fopensearch_log)
* [Coveralls](https://coveralls.io/github/andgineer/opensearch-log)
